/*
	LoadBookMarks.js

	from http://www.macromedia.com/devnet/server_archive/articles/roll_your_own_hs_studio.html
	by Dan Hulse

	Load current bookmarks from a file...
	
	File is an "INI" style format, with a file name 
	matched to bookmarks in a comma-delimited format. E.g.:

		C:\Inetpub\wwwroot\catalog.htm=12,20,55

Before running this script, ensure that the variable sMarkFile points to a 
valid location for your system. Note that in JScript, the backslash used 
for the path separator needs to be "escaped" out in a JScript string by 
preceding it with another backslash character.

*/


function Main() {
	var iSelStart;
	var iSelLen;
	var sMarkFile 	= 'C:\\Program Files\\Allaire\\ColdFusion Studio 4.5\\UserData\\BookMarks.dat';
	
	with (Application.ActiveDocument){

		// Save current selection
		iSelStart = SelStart;
		iSelLen   = SelLength;
		
		try{
			// Prevent editor updates
			BeginUpdate();

			LoadBookMarks(sMarkFile);
		}
		finally{
			// Restore selection			
			SelStart  = iSelStart;
			SelLength = iSelLen;

			// Restore editor updates
			EndUpdate();
		}
	}
}



function LoadBookMarks(sFileName){
	var aMarkSets;
	var aMarks;
	var iCount;
	var sMarkLine;
	var iPos;
	var sCurrDoc = Application.ActiveDocument.Filename;

	aMarkSets = FileToArray(sFileName);

	if (aMarkSets.length == 0)
		return;
	
	for (iCount = 0; iCount < aMarkSets.length; iCount++){
		sMarkLine 	= aMarkSets[iCount];
		iPos 		= sMarkLine.indexOf(sCurrDoc + '=');
		
		if (iPos >= 0)
			break;
	}
	if (iPos < 0)
		return;
		
	iPos 		= (sMarkLine.indexOf('=') + 1);
	sMarkLine 	= sMarkLine.substring(iPos, sMarkLine.length);
	aMarks 		= sMarkLine.split(',');
		
	with (Application.ActiveDocument){
		for (iCount = 0; iCount < aMarks.length; iCount++){
			SelectLine(aMarks[iCount]);
			Application.ExecCommand(59, 0);
		}
	}
}

function FileToArray(sFileName){
	var aFileObj	= new ActiveXObject("Scripting.FileSystemObject");
	var ForReading	= 1;
	var aTextStream;
	var aFile;	
	var sText;
	var aArray;
	
	if (!aFileObj.FileExists(sFileName))
		return(new Array());
		
	aFile = aFileObj.GetFile(sFileName);
	if (aFile.Size == 0)
		return(new Array());
			
	aTextStream = aFileObj.OpenTextFile(sFileName, ForReading);
	
	try{
		sText	= aTextStream.ReadAll();
		aArray 	= sText.split('\r\n');
	}
	finally{
		aTextStream.Close()
	}
	
	return(aArray);
}
