/*
	SaveBookMarks.js

	from http://www.macromedia.com/devnet/server_archive/articles/roll_your_own_hs_studio.html
	by Dan Hulse

	Save current bookmarks to a file...
	
	File is an "INI" style format, with a file name 
	matched to bookmarks in a comma-delimited format. E.g.:

	C:\Inetpub\wwwroot\catalog.htm=12,20,55

Before running this script, ensure that the variable sMarkFile points to a 
valid location for your system. Note that in JScript, the backslash used 
for the path separator needs to be "escaped" out in a JScript string by 
preceding it with another backslash character.

*/


function Main() {
		var iSelStart;
var iSelLen;
	var sMarkFile 	= 'C:\\Program Files\\Allaire\\ColdFusion Studio 4.5\\UserData\\BookMarks.dat';
	
	with (Application.ActiveDocument){

		// Save current selection
		iSelStart = SelStart;
		iSelLen   = SelLength;
		
		try{
			// Prevent editor updates
			BeginUpdate();

			SaveBookMarks(sMarkFile);
		}
		finally{
			// Restore selection			
			SelStart  = iSelStart;
			SelLength = iSelLen;

			// Restore editor updates
			EndUpdate();
		}
	}
}


function SaveBookMarks(sFileName){
	var aMarkSets;
	var aMarks = new Array();
	var sMarkLine;
	var iPos;
	var i;
	var iStartPos;
	var iLine;
	var sLine;

	with (Application.ActiveDocument){
	
		sMarkLine	= Filename + '=';
		aMarkSets	= FileToArray(sFileName);

		// Check if this file is currently in the bookmarks file and delete it
		for (iPos = 0; iPos < aMarkSets.length; iPos++){
			sLine = aMarkSets[iPos];

			if (sLine.indexOf(sMarkLine) >= 0){
				
				// Shift remaining entries up one element
				for (i = iPos; i < aMarkSets.length - 1; i++){
					aMarkSets[i] = aMarkSets[i + 1];
				}
				
				// Adjust array size so the last element is deleted 
				aMarkSets.length = aMarkSets.length - 1;
			
				break;
			}
		}

		try{
			CursorDocStart(false);
			CursorLineEnd(false);
			iStartPos = SelStart;
			
			// Go to next bookmark
			Application.ExecCommand(60, 0);
			
			// If the cursor hasn't moved, then no bookmarks present?
			if (SelStart == iStartPos)
				return;

			iLine = LineNo(Text, SelStart);

			while (true){
				aMarks.length = aMarks.length + 1;
				aMarks[aMarks.length - 1] = iLine;
				
				// Go to next bookmark
				Application.ExecCommand(60, 0);
				
				iLine = LineNo(Text, SelStart);

				// if we are back at the first bookmark, then we are done
				if (aMarks[0] == iLine)
					break;
			}

			// append the comma-delimited line numbers
			sMarkLine = sMarkLine + aMarks.join(',');
			
			// add current bookmark set to existing ones
			aMarkSets.length = aMarkSets.length + 1;
			aMarkSets[aMarkSets.length - 1] = sMarkLine;
		}
		finally{
			ArrayToFile(sFileName, aMarkSets);
		}
	}
}


function ArrayToFile(sFileName, aArray){
	var aFileObj	= new ActiveXObject("Scripting.FileSystemObject");
	var ForWriting	= 2;
	var aTextStream;
	
	if (!aFileObj.FileExists(sFileName))
		aFileObj.CreateTextFile(sFileName, true);

	aTextStream = aFileObj.OpenTextFile(sFileName, ForWriting);
	aTextStream.Write(aArray.join('\r\n'));
	aTextStream.Close();
}


function FileToArray(sFileName){
	var aFileObj	= new ActiveXObject("Scripting.FileSystemObject");
	var ForReading	= 1;
	var aTextStream;
	var aFile;	
	var sText;
	var aArray;
	
	if (!aFileObj.FileExists(sFileName))
		return(new Array());
		
	aFile = aFileObj.GetFile(sFileName);
	if (aFile.Size == 0)
		return(new Array());
			
	aTextStream = aFileObj.OpenTextFile(sFileName, ForReading);
	
	try{
		sText	= aTextStream.ReadAll();
		aArray 	= sText.split('\r\n');
	}
	finally{
		aTextStream.Close()
	}
	
	return(aArray);
}


function LineNo(sText, iOffSet){
	var iPos;
	var iLine;
	
	iPos  = 0;
	iLine = 1;

	while (iPos < iOffSet){
		if (sText.substr(iPos, 2) == '\r\n'){
			iLine++;
			
			// Increment the offset to account for line feeds
			iOffSet++;

			// skip past the \n 
			iPos++;
		}
		
		iPos++;
	}
	
	return iLine;
}
